@@ -62,11 +62,11 @@
 #include <kdevplugininfo.h>
 
 typedef KDevGenericFactory<CustomProjectPart> CustomProjectFactory;
-static const KDevPluginInfo data( "kdevcustomproject" );
-K_EXPORT_COMPONENT_FACTORY( libkdevcustomproject, CustomProjectFactory( data ) )
+static const KDevPluginInfo pluginData( "kdevcustomproject" );
+K_EXPORT_COMPONENT_FACTORY( libkdevcustomproject, CustomProjectFactory( pluginData ) )
 
 CustomProjectPart::CustomProjectPart( TQObject *parent, const char *name, const TQStringList & )
-        : KDevBuildTool( &data, parent, name ? name : "CustomProjectPart" )
+        : KDevBuildTool( &pluginData, parent, name ? name : "CustomProjectPart" )
         , m_lastCompilationFailed( false ), m_recursive( false ), m_first_recursive( false )
 {
     setInstance( CustomProjectFactory::instance() );
