@@ -649,16 +649,6 @@ void QMakeScopeItem::buildGroups()
         item->files.append( createFileItem( *it ) );
     }
 
-    if ( scope->isTQt4Project() )
-    {
-        values = scope->variableValues( "RESOURCES" );
-        item = createGroupItem( GroupItem::Resources, "RESOURCES", this );
-        groups.insert( item->groupType, item );
-        for ( it = values.begin(); it != values.end(); ++it )
-        {
-            item->files.append( createFileItem( *it ) );
-        }
-    }
     values = scope->variableValues( "IMAGES" );
     item = createGroupItem( GroupItem::Images, "IMAGES", this );
     groups.insert( item->groupType, item );
@@ -925,5 +915,3 @@ TQMap<TQString, TQString> QMakeScopeItem::getLibInfos( TQString basePath )
     kdDebug(9024) << "Running getLibInfo for" << scope->projectName() << "|" << map << endl;
     return result;
 }
-
-// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
