@@ -255,7 +255,7 @@ TQString TrollProjectPart::makeEnvironment()
         environstr += " ";
     }
 
-    if( !hasTQtDir && !isTQt4Project() && !DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "").isEmpty() )
+    if( !hasTQtDir && !DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "").isEmpty() )
     {
          environstr += TQString( "TQTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + TQString( " PATH=$TQTDIR/bin:$PATH " );
     }
@@ -291,7 +291,7 @@ void TrollProjectPart::openProject(const TQString &dirName, const TQString &proj
     mainWindow()->statusBar()->message( i18n("Loading Project...") );
 
     TQString defaultTQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
-    if( !isTQt4Project() && ( defaultTQtDir.isEmpty() || !isValidTQtDir( defaultTQtDir ) ) )
+    if( defaultTQtDir.isEmpty() || !isValidTQtDir( defaultTQtDir ) )
     {
         bool doask = true;
         while( doask )
@@ -705,11 +705,6 @@ void TrollProjectPart::startTQMakeCommand(const TQString &dir, bool recursive)
         cmdline = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "")+" ";
     }
 
-    if(isTQt4Project() && recursive)
-    {
-        cmdline += " -recursive ";
-    }
-
     //TQString cmdline = TQString::fromLatin1( isTMakeProject() ? "tmake " : "qmake " );
 //    cmdline += fi.baseName() + ".pro";
     TQDir d(dir);
@@ -798,18 +793,15 @@ bool TrollProjectPart::isValidTQtDir( const TQString& path ) const
     TQFileInfo inc( path + TQString( TQChar( TQDir::separator() ) )+
                    "include"+TQString( TQChar( TQDir::separator() ) )+
                    "tqt.h" );
-    return ( isTQt4Project() || ( !isTQt4Project() && inc.exists() ) );
+    return ( inc.exists() );
 }
 
 void TrollProjectPart::buildBinDirs( TQStringList & dirs ) const
 {
-    if( !isTQt4Project() )
-    {
-        TQString m_defaultTQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
-        if( !m_defaultTQtDir.isEmpty() )
-            dirs << (m_defaultTQtDir + TQString( TQChar( TQDir::separator() ) ) + "bin" );
-        dirs << ( ::getenv("TQTDIR") + TQString( TQChar( TQDir::separator() ) ) + "bin" );
-    }
+    TQString m_defaultTQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
+    if( !m_defaultTQtDir.isEmpty() )
+        dirs << (m_defaultTQtDir + TQString( TQChar( TQDir::separator() ) ) + "bin" );
+    dirs << ( ::getenv("TQTDIR") + TQString( TQChar( TQDir::separator() ) ) + "bin" );
     TQStringList paths = TQStringList::split(":",::getenv("PATH"));
     dirs += paths;
     TQString binpath = TQDir::rootDirPath() + "bin";
@@ -850,8 +842,7 @@ bool TrollProjectPart::isExecutable( const TQString& path ) const
 TQString TrollProjectPart::findTQtDir()
 {
     TQStringList qtdirs;
-    if( !isTQt4Project() )
-        qtdirs.push_back( ::getenv("TQTDIR") );
+    qtdirs.push_back( ::getenv("TQTDIR") );
     qtdirs.push_back( TQDir::rootDirPath()+"usr"+TQString( TQChar( TQDir::separator() ) )+"lib"+TQString( TQChar( TQDir::separator() ) )+"qt"+TQString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
     qtdirs.push_back( TQDir::rootDirPath()+"usr"+TQString( TQChar( TQDir::separator() ) )+"lib"+TQString( TQChar( TQDir::separator() ) )+"qt"+TQString( TQChar( TQDir::separator() ) )+TQString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
     qtdirs.push_back( TQDir::rootDirPath()+"usr"+TQString( TQChar( TQDir::separator() ) )+"share"+TQString( TQChar( TQDir::separator() ) )+"qt"+TQString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
@@ -909,11 +900,6 @@ TQStringList TrollProjectPart::distFiles() const
 	return sourceList + files;
 }
 
-bool TrollProjectPart::isTQt4Project() const
-{
-	return ( DomUtil::readIntEntry( *projectDom(), "kdevcppsupport/qt/version", 3 ) == 4 );
-}
-
 KDirWatch* TrollProjectPart::dirWatch()
 {
     return m_dirWatch;
