@@ -13,11 +13,11 @@
 #include "editorchooser_widget.h"
 
 typedef KDevGenericFactory<EditorChooserPart> EditorChooserFactory;
-static const KDevPluginInfo data("kdeveditorchooser");
-K_EXPORT_COMPONENT_FACTORY( libkdeveditorchooser, EditorChooserFactory( data ) )
+static const KDevPluginInfo pluginData("kdeveditorchooser");
+K_EXPORT_COMPONENT_FACTORY( libkdeveditorchooser, EditorChooserFactory( pluginData ) )
 
 EditorChooserPart::EditorChooserPart(TQObject *parent, const char *name, const TQStringList &)
-  : KDevPlugin(&data, parent, name ? name : "EditorChooserPart")
+  : KDevPlugin(&pluginData, parent, name ? name : "EditorChooserPart")
 {
   setInstance(EditorChooserFactory::instance());
 
