@@ -169,7 +169,7 @@ void FormWindow::init()
     unclippedPainter = 0;
     widgetPressed = FALSE;
     drawRubber = FALSE;
-    setFocusPolicy( TQ_ClickFocus );
+    setFocusPolicy( TQWidget::ClickFocus );
     sizePreviewLabel = 0;
     checkSelectionsTimer = new TQTimer( this, "checkSelectionsTimer" );
     connect( checkSelectionsTimer, TQT_SIGNAL( timeout() ),
@@ -198,7 +198,7 @@ void FormWindow::init()
 	     this, TQT_SLOT( modificationChanged( bool ) ) );
     buffer = 0;
 
-    TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( TQFRAME_OBJECT_NAME_STRING ), this );
+    TQWidget *w = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQFrame" ), this );
     setMainContainer( w );
     propertyWidget = TQT_TQOBJECT(w);
     targetContainer = 0;
@@ -355,7 +355,7 @@ void FormWindow::insertWidget()
     bool useSizeHint = !oldRectValid || ( currRect.width() < 2 && currRect.height() < 2 );
     Qt::Orientation orient =Qt::Horizontal;
     TQString n = WidgetDatabase::className( currTool );
-    if (  useSizeHint && ( n == "Spacer" || n == TQSLIDER_OBJECT_NAME_STRING || n == "Line" || n == TQSCROLLBAR_OBJECT_NAME_STRING ) ) {
+    if (  useSizeHint && ( n == "Spacer" || n == "TQSlider" || n == "Line" || n == "TQScrollBar" ) ) {
 	TQPopupMenu m( mainWindow() );
 	m.insertItem( i18n( "&Horizontal" ) );
 	int ver = m.insertItem( i18n( "&Vertical" ) );
@@ -435,7 +435,7 @@ void FormWindow::insertWidget()
 	    ++it;
 	    if ( o->isWidgetType() &&
 		 ( (TQWidget*)o )->isVisibleTo( this ) &&
-		 insertedWidgets.find( TQT_TQWIDGET(o) ) && TQT_BASE_OBJECT(o) != TQT_BASE_OBJECT(w) ) {
+		 insertedWidgets.find( o ) && o != w ) {
 		TQRect r2( ( (TQWidget*)o )->pos(),
 			  ( (TQWidget*)o )->size() );
 		if ( r.contains( r2 ) )
@@ -594,7 +594,7 @@ void FormWindow::handleMousePress( TQMouseEvent *e, TQWidget *w )
 		} else { // ...widget selected
 		    // only if widget has a layout (it is a layout meta widget or a laid out container!), unselect its childs
 		    if ( WidgetFactory::layoutType( w ) != WidgetFactory::NoLayout ) {
-			TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+			TQObjectList *l = w->queryList( "TQWidget" );
 			setPropertyShowingBlocked( TRUE );
 			for ( TQObject *o = l->first(); o; o = l->next() ) {
 			    if ( !o->isWidgetType() )
@@ -737,7 +737,7 @@ void FormWindow::handleMouseDblClick( TQMouseEvent *, TQWidget *w )
 	}
     default:
 	if ( !WidgetFactory::isPassiveInteractor( TQT_TQOBJECT(w) ) &&
-	     ( isMainContainer( TQT_TQOBJECT(w) ) || TQT_BASE_OBJECT(w) == TQT_BASE_OBJECT(this) ) )
+	     ( isMainContainer( w ) || w == this ) )
 	    mainWindow()->editSource();
 	break;
     }
@@ -1160,7 +1160,7 @@ void FormWindow::handleKeyPress( TQKeyEvent *e, TQWidget *w )
 	}
     }
     if ( !e->isAccepted() ) {
-	TQObjectList *l = queryList( TQWIDGET_OBJECT_NAME_STRING );
+	TQObjectList *l = queryList( "TQWidget" );
 	if ( !l )
 	    return;
 	if ( l->find( TQT_TQOBJECT(w) ) != -1 )
@@ -1365,7 +1365,7 @@ void FormWindow::endRectDraw()
 
 void FormWindow::selectWidgets()
 {
-    TQObjectList *l = mainContainer()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = mainContainer()->queryList( "TQWidget" );
     if ( l ) {
 	for ( TQObject *o = l->first(); o; o = l->next() ) {
 	    if ( ( (TQWidget*)o )->isVisibleTo( this ) &&
@@ -1420,7 +1420,7 @@ void FormWindow::redo()
 
 void FormWindow::raiseChildSelections( TQWidget *w )
 {
-    TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = w->queryList( "TQWidget" );
     if ( !l || !l->first() ) {
 	delete l;
 	return;
@@ -1436,7 +1436,7 @@ void FormWindow::raiseChildSelections( TQWidget *w )
 
 void FormWindow::updateChildSelections( TQWidget *w )
 {
-    TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = w->queryList( "TQWidget" );
     if ( l ) {
 	for ( TQObject *o = l->first(); o; o = l->next() ) {
 	    if ( o->isWidgetType() &&
@@ -1451,7 +1451,7 @@ void FormWindow::checkSelectionsForMove( TQWidget *w )
 {
     checkedSelectionsForMove = TRUE;
 
-    TQObjectList *l = w->parentWidget()->queryList( TQWIDGET_OBJECT_NAME_STRING, 0, FALSE, FALSE );
+    TQObjectList *l = w->parentWidget()->queryList( "TQWidget", 0, FALSE, FALSE );
     moving.clear();
     if ( l ) {
 	TQPtrDictIterator<WidgetSelection> it( usedSelections );
@@ -1569,7 +1569,7 @@ void FormWindow::invalidCheckedSelections()
 
 void FormWindow::checkPreviewGeometry( TQRect &r )
 {
-    if ( !TQT_TQRECT_OBJECT(rect()).contains( r ) ) {
+    if ( !rect().contains( r ) ) {
 	if ( r.left() < rect().left() )
 	    r.moveTopLeft( TQPoint( 0, r.top() ) );
 	if ( r.right() > rect().right()  )
@@ -1613,7 +1613,7 @@ void FormWindow::resizeEvent( TQResizeEvent *e )
 void FormWindow::windowsRepaintWorkaroundTimerTimeout()
 {
 #if defined(TQ_WS_WIN32)
-    TQObjectList *l = queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = queryList( "TQWidget" );
     for ( TQObject *o = l->first(); o; o = l->next() ) {
 	flickerfree_update( (TQWidget*)o );
     }
@@ -1771,7 +1771,7 @@ void FormWindow::showOrderIndicators()
 {
     hideOrderIndicators();
     orderIndicators.setAutoDelete( TRUE );
-    TQObjectList *l = mainContainer()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = mainContainer()->queryList( "TQWidget" );
     stackedWidgets = MetaDataBase::tabOrder( this );
     if ( l ) {
 	int order = 1;
@@ -1779,7 +1779,7 @@ void FormWindow::showOrderIndicators()
 	    TQWidget* w = (TQWidget*) o;
 	    if ( w->isShown() &&
 		 insertedWidgets[ (void*)w ]  &&
-		 w->focusPolicy() != TQ_NoFocus ) {
+		 w->focusPolicy() != TQWidget::NoFocus ) {
 		OrderIndicator* ind = new OrderIndicator( order++, w, this );
 		orderIndicators.append( ind );
 		if ( stackedWidgets.findRef( w ) == -1 )
@@ -1903,7 +1903,7 @@ void FormWindow::checkAccels()
 {
     CHECK_MAINWINDOW;
     TQMap<TQChar, TQWidgetList > accels;
-    TQObjectList *l = mainContainer()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = mainContainer()->queryList( "TQWidget" );
     if ( l ) {
 	for ( TQObject *o = l->first(); o; o = l->next() ) {
 	    if ( ( (TQWidget*)o )->isVisibleTo( this ) &&
@@ -1978,7 +1978,7 @@ void FormWindow::selectAll()
 {
     checkedSelectionsForMove = FALSE;
     blockSignals( TRUE );
-    TQObjectList *l = mainContainer()->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = mainContainer()->queryList( "TQWidget" );
     if ( l ) {
 	for ( TQObject *o = l->first(); o; o = l->next() ) {
 	    if ( ( (TQWidget*)o )->isVisibleTo( this ) &&
@@ -2181,7 +2181,7 @@ bool FormWindow::hasInsertedChildren( TQWidget *w ) const
     w = WidgetFactory::containerOfWidget( w );
     if ( !w )
 	return FALSE;
-    TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = w->queryList( "TQWidget" );
     if ( !l || !l->first() ) {
 	delete l;
 	return FALSE;
@@ -2361,7 +2361,7 @@ bool FormWindow::unify( TQObject *w, TQString &s, bool changeIt )
 	int num  = 1;
 	TQPtrDictIterator<TQWidget> it( insertedWidgets );
 	for ( ; it.current();) {
-	    if ( TQT_BASE_OBJECT(it.current()) != TQT_BASE_OBJECT(w) &&
+	    if ( it.current() != w &&
 		 qstrcmp( it.current()->name(), s.latin1() ) == 0 ) {
 		found = TRUE;
 		if ( !changeIt )
@@ -2376,7 +2376,7 @@ bool FormWindow::unify( TQObject *w, TQString &s, bool changeIt )
 	    TQPtrList<TQAction> al;
 	    TQAction *a = 0;
 	    for ( a = actions.first(); a; a = actions.next() ) {
-		TQObjectList *l = a->queryList( TQACTION_OBJECT_NAME_STRING );
+		TQObjectList *l = a->queryList( "TQAction" );
 		al.append( a );
 		for ( TQObject *ao = l->first(); ao; ao = l->next() )
 		    al.append( (TQAction*)ao );
@@ -2409,7 +2409,7 @@ bool FormWindow::unify( TQObject *w, TQString &s, bool changeIt )
 	}
 	if ( ::tqqt_cast<TQMainWindow*>(mainContainer()) ) {
 	    if ( !found ) {
-		TQObjectList *l = mainContainer()->queryList( TQDOCKWINDOW_OBJECT_NAME_STRING, 0, TRUE );
+		TQObjectList *l = mainContainer()->queryList( "TQDockWindow", 0, TRUE );
 		for ( TQObject *o = l->first(); o; o = l->next() ) {
 		    if ( o != w &&
 			 qstrcmp( o->name(), s.latin1() ) == 0 ) {
@@ -2447,7 +2447,7 @@ bool FormWindow::isDatabaseWidgetUsed() const
 {
 #ifndef TQT_NO_SQL
     TQStringList dbClasses;
-    dbClasses << TQDATATABLE_OBJECT_NAME_STRING; // add more here
+    dbClasses << "TQDataTable"; // add more here
     TQPtrDictIterator<TQWidget> it( insertedWidgets );
     for ( ; it.current(); ++it ) {
 	TQString c( it.current()->className() );
@@ -2525,7 +2525,7 @@ TQWidget *FormWindow::containerAt( const TQPoint &pos, TQWidget *notParentOf )
     TQWidget *container = 0;
     int depth = -1;
     TQWidgetList selected = selectedWidgets();
-    if ( TQT_TQRECT_OBJECT(rect()).contains( mapFromGlobal( pos ) ) ) {
+    if ( rect().contains( mapFromGlobal( pos ) ) ) {
 	container = mainContainer();
 	depth = widgetDepth( container );
     }
@@ -2545,7 +2545,7 @@ TQWidget *FormWindow::containerAt( const TQPoint &pos, TQWidget *notParentOf )
 	// the rectangles of all ancestors of the container must contain the insert position
 	TQWidget *w = it.current();
 	while ( w && !w->isTopLevel() ) {
-	    if ( !TQT_TQRECT_OBJECT(w->rect()).contains( ( w->mapFromGlobal( pos ) ) ) )
+	    if ( !w->rect().contains( ( w->mapFromGlobal( pos ) ) ) )
 		break;
 	    w = w->parentWidget();
 	}
@@ -2568,7 +2568,7 @@ TQWidget *FormWindow::containerAt( const TQPoint &pos, TQWidget *notParentOf )
 
 bool FormWindow::isMainContainer( TQObject *w ) const
 {
-    return w && w->isWidgetType() && ( TQT_BASE_OBJECT(w) == this || TQT_BASE_OBJECT(w) == mainContainer() );
+    return w && w->isWidgetType() && ( w == this || w == mainContainer() );
 }
 
 void FormWindow::setMainContainer( TQWidget *w )
@@ -2576,7 +2576,7 @@ void FormWindow::setMainContainer( TQWidget *w )
     bool resetPropertyWidget = isMainContainer( propertyWidget );
     if ( mContainer )
 	insertedWidgets.remove( mContainer );
-    if ( TQT_BASE_OBJECT(propertyWidget) == TQT_BASE_OBJECT(mContainer) )
+    if ( propertyWidget == mContainer )
 	propertyWidget = 0;
     delete mContainer;
     mContainer = w;
@@ -2663,7 +2663,7 @@ TQAction *FormWindow::findAction( const TQString &name )
     for ( TQAction *a = actionList().first(); a; a = actionList().next() ) {
 	if ( TQString( a->name() ) == name )
 	    return a;
-	TQAction *ac = (TQAction*)a->child( name.latin1(), TQACTION_OBJECT_NAME_STRING );
+	TQAction *ac = (TQAction*)a->child( name.latin1(), "TQAction" );
 	if ( ac )
 	    return ac;
     }
@@ -2672,7 +2672,7 @@ TQAction *FormWindow::findAction( const TQString &name )
 
 void FormWindow::killAccels( TQObject *top )
 {
-    TQObjectList *l = top->queryList( TQACCEL_OBJECT_NAME_STRING );
+    TQObjectList *l = top->queryList( "TQAccel" );
     if ( !l )
 	return;
     for ( TQObject *o = l->first(); o; o = l->next() )
@@ -2691,7 +2691,7 @@ bool FormWindow::isCentralWidget( TQObject *w ) const
 {
     if ( !::tqqt_cast<TQMainWindow*>(mainContainer()) )
 	return FALSE;
-    return TQT_BASE_OBJECT(w) == TQT_BASE_OBJECT(( (TQMainWindow*)mainContainer() )->centralWidget());
+    return w == ((TQMainWindow*)mainContainer())->centralWidget();
 }
 
 int FormWindow::layoutDefaultSpacing() const
@@ -2758,7 +2758,7 @@ void FormWindow::setFormFile( FormFile *f )
 
 bool FormWindow::canBeBuddy( const TQWidget *w ) const
 {
-    return w->focusPolicy() != TQ_NoFocus;
+    return w->focusPolicy() != TQWidget::NoFocus;
 }
 
 bool FormWindow::event( TQEvent *e )
