@@ -170,10 +170,10 @@ bool Layout::prepareLayout( bool &needMove, bool &needReparent )
     needReparent = needMove || ::tqqt_cast<TQLayoutWidget*>(layoutBase) || ::tqqt_cast<TQSplitter*>(layoutBase);
     if ( !layoutBase ) {
 	if ( !useSplitter )
-	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( TQLAYOUTWIDGET_OBJECT_NAME_STRING ),
+	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQLayoutWidget" ),
 						WidgetFactory::containerOfWidget( parent ) );
 	else
-	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( TQSPLITTER_OBJECT_NAME_STRING ),
+	    layoutBase = WidgetFactory::create( WidgetDatabase::idFromClassName( "TQSplitter" ),
 						WidgetFactory::containerOfWidget( parent ) );
     } else {
 	WidgetFactory::deleteLayout( layoutBase );
@@ -239,11 +239,11 @@ void Layout::breakLayout()
 	    rects.insert( w, w->geometry() );
     }
     WidgetFactory::deleteLayout( layoutBase );
-    bool needReparent = qstrcmp( layoutBase->className(), TQLAYOUTWIDGET_OBJECT_NAME_STRING ) == 0 ||
-			qstrcmp( layoutBase->className(), TQSPLITTER_OBJECT_NAME_STRING ) == 0 ||
+    bool needReparent = qstrcmp( layoutBase->className(), "TQLayoutWidget" ) == 0 ||
+			qstrcmp( layoutBase->className(), "TQSplitter" ) == 0 ||
 			( !WidgetDatabase::isContainer( WidgetDatabase::idFromClassName( WidgetFactory::classNameOf( TQT_TQOBJECT(layoutBase) ) ) ) &&
 			  layoutBase != formWindow->mainContainer() );
-    bool needResize = qstrcmp( layoutBase->className(), TQSPLITTER_OBJECT_NAME_STRING ) == 0;
+    bool needResize = qstrcmp( layoutBase->className(), "TQSplitter" ) == 0;
     bool add = geometries.isEmpty();
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
 	if ( needReparent )
@@ -314,7 +314,7 @@ void HorizontalLayout::doLayout()
     TQHBoxLayout *layout = (TQHBoxLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::HBox );
 
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
-	if ( needReparent && TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(layoutBase) )
+	if ( needReparent && w->parent() != layoutBase )
 	    w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	if ( !useSplitter ) {
 	    if ( qstrcmp( w->className(), "Spacer" ) == 0 )
@@ -378,7 +378,7 @@ void VerticalLayout::doLayout()
     TQVBoxLayout *layout = (TQVBoxLayout*)WidgetFactory::createLayout( layoutBase, 0, WidgetFactory::VBox );
 
     for ( TQWidget *w = widgets.first(); w; w = widgets.next() ) {
-	if ( needReparent && TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(layoutBase) )
+	if ( needReparent && w->parent() != layoutBase )
 	    w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	if ( !useSplitter ) {
 	    if ( qstrcmp( w->className(), "Spacer" ) == 0 )
@@ -756,7 +756,7 @@ void GridLayout::doLayout()
     int r, c, rs, cs;
     for ( w = widgets.first(); w; w = widgets.next() ) {
 	if ( grid->locateWidget( w, r, c, rs, cs) ) {
-	    if ( needReparent && TQT_BASE_OBJECT(w->parent()) != TQT_BASE_OBJECT(layoutBase) )
+	    if ( needReparent && w->parent() != layoutBase )
 		w->reparent( layoutBase, 0, TQPoint( 0, 0 ), FALSE );
 	    if ( rs * cs == 1 ) {
 		layout->addWidget( w, r, c, ::tqqt_cast<Spacer*>(w) ? ( (Spacer*)w )->alignment() : 0 );
