@@ -440,10 +440,10 @@ void MetaDataBase::addConnection( TQObject *o, TQObject *sender, const TQCString
     r->connections.append( conn );
     if ( addCode ) {
 	TQString rec = receiver->name();
-	if ( ::tqqt_cast<FormWindow*>(o) && TQT_BASE_OBJECT(receiver) ==( (FormWindow*)o )->mainContainer() )
+	if ( ::tqqt_cast<FormWindow*>(o) && receiver ==( (FormWindow*)o )->mainContainer() )
 	    rec = "this";
 	TQString sen = sender->name();
-	if ( ::tqqt_cast<FormWindow*>(o) && TQT_BASE_OBJECT(sender) ==( (FormWindow*)o )->mainContainer() )
+	if ( ::tqqt_cast<FormWindow*>(o) && sender ==( (FormWindow*)o )->mainContainer() )
 	    sen = "this";
 	FormFile *ff = 0;
 	if ( ::tqqt_cast<FormFile*>(o) )
@@ -468,9 +468,9 @@ void MetaDataBase::removeConnection( TQObject *o, TQObject *sender, const TQCStr
 	return;
     for ( TQValueList<Connection>::Iterator it = r->connections.begin(); it != r->connections.end(); ++it ) {
 	Connection conn = *it;
-	if ( TQT_BASE_OBJECT(conn.sender) ==sender &&
+	if ( conn.sender ==sender &&
 	     conn.signal == signal &&
-	     TQT_BASE_OBJECT(conn.receiver) ==receiver &&
+	     conn.receiver ==receiver &&
 	     conn.slot == slot ) {
 	    r->connections.remove( it );
 	    break;
@@ -478,7 +478,7 @@ void MetaDataBase::removeConnection( TQObject *o, TQObject *sender, const TQCStr
     }
     if ( ::tqqt_cast<FormWindow*>(o) ) {
 	TQString rec = receiver->name();
-	if ( TQT_BASE_OBJECT(receiver) ==( (FormWindow*)o )->mainContainer() )
+	if ( receiver ==( (FormWindow*)o )->mainContainer() )
 	    rec = "this";
 	( (FormWindow*)o )->formFile()->removeConnection( sender->name(), signal, rec, slot );
     }
@@ -544,9 +544,9 @@ bool MetaDataBase::hasConnection( TQObject *o, TQObject *sender, const TQCString
 
     for ( TQValueList<Connection>::Iterator it = r->connections.begin(); it != r->connections.end(); ++it ) {
 	Connection conn = *it;
-	if ( TQT_BASE_OBJECT(conn.sender) ==sender &&
+	if ( conn.sender ==sender &&
 	     conn.signal == signal &&
-	     TQT_BASE_OBJECT(conn.receiver) ==receiver &&
+	     conn.receiver ==receiver &&
 	     conn.slot == slot )
 	    return TRUE;
     }
@@ -581,8 +581,8 @@ TQValueList<MetaDataBase::Connection> MetaDataBase::connections( TQObject *o, TQ
     TQValueList<Connection>::Iterator conn;
     while ( ( conn = it ) != r->connections.end() ) {
 	++it;
-	if ( TQT_BASE_OBJECT((*conn).sender) ==sender &&
-	     TQT_BASE_OBJECT((*conn).receiver) ==receiver )
+	if ( (*conn).sender ==sender &&
+	     (*conn).receiver ==receiver )
 	    ret << *conn;
     }
 
@@ -603,8 +603,8 @@ TQValueList<MetaDataBase::Connection> MetaDataBase::connections( TQObject *o, TQ
     TQValueList<Connection>::Iterator conn;
     while ( ( conn = it ) != r->connections.end() ) {
 	++it;
-	if ( TQT_BASE_OBJECT((*conn).sender) ==object ||
-	     TQT_BASE_OBJECT((*conn).receiver) ==object )
+	if ( (*conn).sender ==object ||
+	     (*conn).receiver ==object )
 	    ret << *conn;
     }
     return ret;
