@@ -304,7 +304,7 @@ void PopupMenuEditor::init()
     addSeparator.action()->setMenuText( i18n("new separator") );
 
     setAcceptDrops( TRUE );
-    setFocusPolicy( TQ_StrongFocus );
+    setFocusPolicy( TQWidget::StrongFocus );
 
     lineEdit = new TQLineEdit( this );
     lineEdit->hide();
@@ -357,7 +357,7 @@ void PopupMenuEditor::insert( TQActionGroup * actionGroup, int index )
     PopupMenuEditorItem *i = new PopupMenuEditorItem( (TQAction *)actionGroup, this, 0,
 						      TQString( actionGroup->name() ) + "Menu" );
     TQActionGroup *g = 0;
-    TQObjectList *l = actionGroup->queryList( TQACTION_OBJECT_NAME_STRING, 0, FALSE, FALSE );
+    TQObjectList *l = actionGroup->queryList( "TQAction", 0, FALSE, FALSE );
     TQObjectListIterator it( *l );
     insert( i, index );
     for ( ; it.current(); ++it ) {
@@ -714,7 +714,7 @@ void PopupMenuEditor::setFocusAt( const TQPoint & pos )
 
 bool PopupMenuEditor::eventFilter( TQObject * o, TQEvent * e )
 {
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(lineEdit)  && e->type() == TQEvent::FocusOut ) {
+    if ( o == lineEdit  && e->type() == TQEvent::FocusOut ) {
 	leaveEditMode( 0 );
 	update();
     }
@@ -863,7 +863,7 @@ void PopupMenuEditor::dropEvent( TQDropEvent * e )
 		TQString n = TQString( g->name() ) + "Item";
 		formWindow()->unify( i, n, FALSE );
 		i->setName( n );
-		TQObjectList *l = g->queryList( TQACTION_OBJECT_NAME_STRING, 0, FALSE, FALSE );
+		TQObjectList *l = g->queryList( "TQAction", 0, FALSE, FALSE );
 		TQObjectListIterator it( *l );
 		for ( ; it.current(); ++it ) {
 		    g = ::tqqt_cast<TQActionGroup*>(it.current());
