@@ -12,7 +12,7 @@ class TQStringList;
 
 class AdaSupportPart : public KDevLanguageSupport
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     AdaSupportPart (TQObject *parent, const char *name, const TQStringList &);
