@@ -7,7 +7,7 @@
 
 class %{APPNAME}Widget : public %{APPNAME}WidgetBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
