@@ -31,7 +31,7 @@ void tdemdikonsole::respawn()
 
 	if (!m_part) return;
 
-	if (m_part->widget()->inherits(TQFRAME_OBJECT_NAME_STRING))
+	if (m_part->widget()->inherits("TQFrame"))
 		((TQFrame*)m_part->widget())->setFrameStyle(TQFrame::Panel|TQFrame::Sunken);
 
 	m_haskonsole=true;
