@@ -19,10 +19,10 @@ int main(int argc, char **argv)
     QByteArray data;
     QDataStream ds(data, IO_WriteOnly);
     if (argc > 1)
-        ds << QString(argv[1]);
+        ds << TQString(argv[1]);
     else
-        ds << QString("http://www.kde.org");
-    client->send("%{APPNAMELC}", "%{APPNAME}Iface", "openURL(QString)", data);
+        ds << TQString("http://www.kde.org");
+    client->send("%{APPNAMELC}", "%{APPNAME}Iface", "openURL(TQString)", data);
 
     return app.exec();
 }
