@@ -15,12 +15,12 @@ class %{APPNAMESC}View < %{APPNAMESC}view_base
     #
     # Use this signal to change the content of the statusbar
     #
-    Q_SIGNALS 'signalChangeStatusbar(const QString&)'
+    Q_SIGNALS 'signalChangeStatusbar(const TQString&)'
 
     #
     # Use this signal to change the content of the caption
     #
-    Q_SIGNALS 'signalChangeCaption(const QString&)'
+    Q_SIGNALS 'signalChangeCaption(const TQString&)'
 
     Q_SLOTS 'switchColors()',
           'settingsChanged()'
