@@ -228,7 +228,7 @@ DbgDocker::DbgDocker(TQWidget* parent, DbgToolBar* toolBar, const TQPixmap& pixm
 
 void DbgDocker::mousePressEvent(TQMouseEvent *e)
 {
-    if (!TQT_TQRECT_OBJECT(rect()).contains( e->pos()))
+    if (!rect().contains( e->pos()))
         return;
 
     switch (e->button()) {
@@ -284,7 +284,7 @@ DbgToolBar::DbgToolBar(RubyDebuggerPart* part,
 //    KWin::setType(winId(), NET::Override);    // So it has no decoration
     KWin::setType(winId(), NET::Dock);
 
-    setFocusPolicy(TQ_NoFocus);
+    setFocusPolicy(TQWidget::NoFocus);
     setFrameStyle( TQFrame::Box | TQFrame::Plain );
     setLineWidth(4);
     setMidLineWidth(0);
