@@ -83,7 +83,7 @@ TQString nodeTypeToString( int type )
 	return "DoStatement";
     case NodeType_ForStatement:
 	return "ForStatement";
-    case NodeType_ForEachStatement: // qt4 [erbsland]
+    case NodeType_ForEachStatement:
 	return "ForEachStatement";
     case NodeType_SwitchStatement:
 	return "SwitchStatement";
