@@ -72,13 +72,13 @@
 #define GLOBALDOC_OPTIONS 1
 #define PROJECTDOC_OPTIONS 2
 
-static const KDevPluginInfo data("kdevdocumentation");
+static const KDevPluginInfo pluginData("kdevdocumentation");
 
 typedef KDevGenericFactory<DocumentationPart> DocumentationFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevdocumentation, DocumentationFactory( data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevdocumentation, DocumentationFactory( pluginData ) )
 
 DocumentationPart::DocumentationPart(TQObject *parent, const char *name, const TQStringList& )
-    :KDevPlugin(&data, parent, name ? name : "DocumentationPart" ),
+    :KDevPlugin(&pluginData, parent, name ? name : "DocumentationPart" ),
     m_projectDocumentationPlugin(0), m_userManualPlugin(0), m_hasIndex(false)
 {
     setInstance(DocumentationFactory::instance());
