@@ -54,16 +54,16 @@
 
 #include "config.h"
 
-static const KDevPluginInfo data("kdevfilecreate");
+static const KDevPluginInfo pluginData("kdevfilecreate");
 
 typedef KDevGenericFactory<FileCreatePart> FileCreateFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( pluginData ) )
 
 using namespace FileCreate;
 
 FileCreatePart::FileCreatePart(TQObject *parent, const char *name, const TQStringList & )
-//    : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
-    : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_subPopups(0)
+//    : KDevCreateFile(&pluginData, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
+    : KDevCreateFile(&pluginData, parent, name ? name : "FileCreatePart"), m_subPopups(0)
 {
   setInstance(FileCreateFactory::instance());
   setXMLFile("kdevpart_filecreate.rc");
