@@ -113,7 +113,7 @@ void ToolsPart::updateMenu()
 
 void ToolsPart::slotToolActivated()
 {
-  TQString df = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name();
+  TQString df = sender()->name();
   kapp->startServiceByDesktopPath(df);
 }
 
@@ -224,7 +224,7 @@ void ToolsPart::contextMenu(TQPopupMenu *popup, const Context *context)
 
 void ToolsPart::toolsMenuActivated()
 {
-    TQString menutext = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name();
+    TQString menutext = sender()->name();
     TDEConfig *config = ToolsFactory::instance()->config();
     config->setGroup("Tool Menu " + menutext);
     TQString cmdline = config->readPathEntry("CommandLine");
