@@ -19,7 +19,7 @@ class PluginController;
 
 class PluginSelectDialog : public PluginSelectDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -39,5 +39,3 @@ protected slots:
 };
 
 #endif
-
-// kate: space-indent off; indent-width 4; tab-width 4; show-tabs off;
