@@ -18,7 +18,7 @@
 
 class CcaseCommentDlg : public TQDialog
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   CcaseCommentDlg(bool = FALSE);
