@@ -10,7 +10,7 @@ namespace SvnGlobal
 
 class SvnSwitchDlg : public SvnSwitchDlgBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	SvnSwitchDlg( const SvnGlobal::SvnInfoHolder *holder,
